package com.bonus.material.repair.mapper;

import java.util.List;
import com.bonus.material.repair.domain.RepairInputDetails;

/**
 * 修试后入库Mapper接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface RepairInputDetailsMapper {
    /**
     * 查询修试后入库
     * 
     * @param id 修试后入库主键
     * @return 修试后入库
     */
    public RepairInputDetails selectRepairInputDetailsById(Long id);

    /**
     * 查询修试后入库列表
     * 
     * @param repairInputDetails 修试后入库
     * @return 修试后入库集合
     */
    public List<RepairInputDetails> selectRepairInputDetailsList(RepairInputDetails repairInputDetails);

    /**
     * 新增修试后入库
     * 
     * @param repairInputDetails 修试后入库
     * @return 结果
     */
    public int insertRepairInputDetails(RepairInputDetails repairInputDetails);

    /**
     * 修改修试后入库
     * 
     * @param repairInputDetails 修试后入库
     * @return 结果
     */
    public int updateRepairInputDetails(RepairInputDetails repairInputDetails);

    /**
     * 删除修试后入库
     * 
     * @param id 修试后入库主键
     * @return 结果
     */
    public int deleteRepairInputDetailsById(Long id);

    /**
     * 批量删除修试后入库
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRepairInputDetailsByIds(Long[] ids);
}
