package com.bonus.material.repair.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.repair.domain.RepairInputDetails;
import com.bonus.material.repair.service.IRepairInputDetailsService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 修试后入库Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "修试后入库接口")
@RestController
@RequestMapping("/repair_input_details")
public class RepairInputDetailsController extends BaseController {
    @Autowired
    private IRepairInputDetailsService repairInputDetailsService;

    /**
     * 查询修试后入库列表
     */
    @ApiOperation(value = "查询修试后入库列表")
    @RequiresPermissions("repair:details:list")
    @GetMapping("/list")
    public TableDataInfo list(RepairInputDetails repairInputDetails) {
        startPage();
        List<RepairInputDetails> list = repairInputDetailsService.selectRepairInputDetailsList(repairInputDetails);
        return getDataTable(list);
    }

    /**
     * 导出修试后入库列表
     */
    @ApiOperation(value = "导出修试后入库列表")
    @PreventRepeatSubmit
    @RequiresPermissions("repair:details:export")
    @SysLog(title = "修试后入库", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出修试后入库")
    @PostMapping("/export")
    public void export(HttpServletResponse response, RepairInputDetails repairInputDetails) {
        List<RepairInputDetails> list = repairInputDetailsService.selectRepairInputDetailsList(repairInputDetails);
        ExcelUtil<RepairInputDetails> util = new ExcelUtil<RepairInputDetails>(RepairInputDetails.class);
        util.exportExcel(response, list, "修试后入库数据");
    }

    /**
     * 获取修试后入库详细信息
     */
    @ApiOperation(value = "获取修试后入库详细信息")
    @RequiresPermissions("repair:details:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(repairInputDetailsService.selectRepairInputDetailsById(id));
    }

    /**
     * 新增修试后入库
     */
    @ApiOperation(value = "新增修试后入库")
    @PreventRepeatSubmit
    @RequiresPermissions("repair:details:add")
    @SysLog(title = "修试后入库", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增修试后入库")
    @PostMapping
    public AjaxResult add(@RequestBody RepairInputDetails repairInputDetails) {
        try {
            return toAjax(repairInputDetailsService.insertRepairInputDetails(repairInputDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改修试后入库
     */
    @ApiOperation(value = "修改修试后入库")
    @PreventRepeatSubmit
    @RequiresPermissions("repair:details:edit")
    @SysLog(title = "修试后入库", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改修试后入库")
    @PutMapping
    public AjaxResult edit(@RequestBody RepairInputDetails repairInputDetails) {
        try {
            return toAjax(repairInputDetailsService.updateRepairInputDetails(repairInputDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除修试后入库
     */
    @ApiOperation(value = "删除修试后入库")
    @PreventRepeatSubmit
    @RequiresPermissions("repair:details:remove")
    @SysLog(title = "修试后入库", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除修试后入库")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(repairInputDetailsService.deleteRepairInputDetailsByIds(ids));
    }
}
